//genesis
// This simulation generates Ca2+ time courses
// when specific pathways are deleted.

include DoiCaModel.g


// Define clocks
float normdt = 1e-06 /* 0 < t < 0.1, 0.6 < t < 0.7, 0.9 < t < 1.5 */
float fastdt = 1e-07 /* 0.5 < t < 0.6, 0.7 < t < 0.9 */
float slowdt = 1e-05 /* 0.1 < t < 0.5, 1.5 < t < 2 */
float plotdt = 0.001

setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}



// Pathway deletion of IP3 -> IP3Rs

echo ""
echo "Pathway deletion of IP3 -> IP3Rs"

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}
MAXTIME = 0.1
step {MAXTIME} -time   /* 0 < t < 0.1 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
setclock 3 {plotdt}
MAXTIME = 0.4
step {MAXTIME} -time   /* 0.1 <t < 0.5 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.1
step {MAXTIME} -time    /* 0.5 < t < 0.6 */


setfield /kinetics/PLC/IP3_PSD slave_enable 4
setfield /kinetics/IP3deg/IP3_spine slave_enable 4

/* Apply fastdt */
setclock 0 {fastdt}
setclock 1 {fastdt}
MAXTIME =   0.2
step {MAXTIME} -time    /* 0.6 < t < 0.8 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.7
step {MAXTIME} -time    /* 0.8 < t < 1.5 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
MAXTIME =   0.5001
SIMDT = {slowdt}
step {MAXTIME} -time    /* 1.5 < t < 2 */

// save data
        do_save_named_plot /graphs/conc2/Ca.Co {"./simresult/fig4/pathdelfig4B_Ca.plot"}

setfield /kinetics/PLC/IP3_PSD slave_enable 0
setfield /kinetics/IP3deg/IP3_spine slave_enable 0
reset



// Pathway deletion of Ca -> IP3Rs

echo ""
echo "Pathway deletion of Ca -> IP3Rs"

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}
MAXTIME = 0.1
step {MAXTIME} -time   /* 0 < t < 0.1 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
setclock 3 {plotdt}
MAXTIME = 0.4
step {MAXTIME} -time   /* 0.1 <t < 0.5 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.1
step {MAXTIME} -time    /* 0.5 < t < 0.6 */

setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kf    0
setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kb    0
setfield /kinetics/IP3R/bypass_for_fig4C kf  133.33
setfield /kinetics/IP3R/bypass_for_fig4C kb 2000

/* Apply fastdt */
setclock 0 {fastdt}
setclock 1 {fastdt}
MAXTIME =   0.2
step {MAXTIME} -time    /* 0.6 < t < 0.8 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.7
step {MAXTIME} -time    /* 0.8 < t < 1.5 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
MAXTIME =   0.5001
SIMDT = {slowdt}
step {MAXTIME} -time    /* 1.5 < t < 2 */

// save data
        do_save_named_plot /graphs/conc2/Ca.Co {"./simresult/fig4/pathdelfig4C_Ca.plot"}

setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kf  133.33
setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kb 2000
setfield /kinetics/IP3R/bypass_for_fig4C kf    0
setfield /kinetics/IP3R/bypass_for_fig4C kb    0
reset



// Pathway deletion of Ca -> PLC

echo ""
echo "Pathway deletion of Ca -> PLC"

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}
MAXTIME = 0.1
step {MAXTIME} -time   /* 0 < t < 0.1 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
setclock 3 {plotdt}
MAXTIME = 0.4
step {MAXTIME} -time   /* 0.1 <t < 0.5 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.1
step {MAXTIME} -time    /* 0.5 < t < 0.6 */

setfield /kinetics/PLC/PLC-PIP2_bind_Ca    kf   0
setfield /kinetics/PLC/PLC-PIP2_bind_Ca    kb   0
setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kf   0
setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kb   0
setfield /kinetics/PLC/bypass0_for_fig4D   kf 250
setfield /kinetics/PLC/bypass0_for_fig4D   kb 100
setfield /kinetics/PLC/bypass1_for_fig4D   kf 750
setfield /kinetics/PLC/bypass1_for_fig4D   kb  30

/* Apply fastdt */
setclock 0 {fastdt}
setclock 1 {fastdt}
MAXTIME =   0.2
step {MAXTIME} -time    /* 0.6 < t < 0.8 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.7
step {MAXTIME} -time    /* 0.8 < t < 1.5 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
MAXTIME =   0.5001
SIMDT = {slowdt}
step {MAXTIME} -time    /* 1.5 < t < 2 */


// save data
        do_save_named_plot /graphs/conc2/Ca.Co {"./simresult/fig4/pathdelfig4D_Ca.plot"}

setfield /kinetics/PLC/PLC-PIP2_bind_Ca    kf 250
setfield /kinetics/PLC/PLC-PIP2_bind_Ca    kb 100
setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kf 750
setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kb  30
setfield /kinetics/PLC/bypass0_for_fig4D   kf   0
setfield /kinetics/PLC/bypass0_for_fig4D   kb   0
setfield /kinetics/PLC/bypass1_for_fig4D   kf   0
setfield /kinetics/PLC/bypass1_for_fig4D   kb   0
reset



// Pathway deletion of Ca -| IP3R

echo ""
echo "Pathway deletion of Ca -| IP3R"

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}
MAXTIME = 0.1
step {MAXTIME} -time   /* 0 < t < 0.1 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
setclock 3 {plotdt}
MAXTIME = 0.4
step {MAXTIME} -time   /* 0.1 <t < 0.5 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.1
step {MAXTIME} -time    /* 0.5 < t < 0.6 */

setfield /kinetics/IP3R/IP3R_bind_Ca      kf  0
setfield /kinetics/IP3R/IP3R_bind_Ca      kb  0
setfield /kinetics/IP3R/IP3R-Ca_bind_Ca   kf  0
setfield /kinetics/IP3R/IP3R-Ca_bind_Ca   kb  0
setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca  kf  0
setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca  kb  0
setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca  kf  0
setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca  kb  0
setfield /kinetics/IP3R/bypass0_for_fig4E kf  0.14815
setfield /kinetics/IP3R/bypass0_for_fig4E kb  5
setfield /kinetics/IP3R/bypass1_for_fig4E kf  0.33333
setfield /kinetics/IP3R/bypass1_for_fig4E kb 10
setfield /kinetics/IP3R/bypass2_for_fig4E kf  0.66667
setfield /kinetics/IP3R/bypass2_for_fig4E kb 15
setfield /kinetics/IP3R/bypass3_for_fig4E kf  1
setfield /kinetics/IP3R/bypass3_for_fig4E kb 20

/* Apply fastdt */
setclock 0 {fastdt}
setclock 1 {fastdt}
MAXTIME =   0.2
step {MAXTIME} -time    /* 0.6 < t < 0.8 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.7
step {MAXTIME} -time    /* 0.8 < t < 1.5 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
MAXTIME =   0.5001
SIMDT = {slowdt}
step {MAXTIME} -time    /* 1.5 < t < 2 */

// save data
        do_save_named_plot /graphs/conc2/Ca.Co {"./simresult/fig4/pathdelfig4E_Ca.plot"}

setfield /kinetics/IP3R/IP3R_bind_Ca      kf  0.14815
setfield /kinetics/IP3R/IP3R_bind_Ca      kb  5
setfield /kinetics/IP3R/IP3R-Ca_bind_Ca   kf  0.33333
setfield /kinetics/IP3R/IP3R-Ca_bind_Ca   kb 10
setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca  kf  0.66667
setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca  kb 15
setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca  kf  1
setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca  kb 20
setfield /kinetics/IP3R/bypass0_for_fig4E kf  0
setfield /kinetics/IP3R/bypass0_for_fig4E kb  0
setfield /kinetics/IP3R/bypass1_for_fig4E kf  0
setfield /kinetics/IP3R/bypass1_for_fig4E kb  0
setfield /kinetics/IP3R/bypass2_for_fig4E kf  0
setfield /kinetics/IP3R/bypass2_for_fig4E kb  0
setfield /kinetics/IP3R/bypass3_for_fig4E kf  0
setfield /kinetics/IP3R/bypass3_for_fig4E kb  0
reset



// Pathway deletion of Ca Release -| Ca Store

echo ""
echo "Pathway deletion of Ca Release -| Ca Store"

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}
MAXTIME = 0.1
step {MAXTIME} -time   /* 0 < t < 0.1 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
setclock 3 {plotdt}
MAXTIME = 0.4
step {MAXTIME} -time   /* 0.1 <t < 0.5 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.1
step {MAXTIME} -time    /* 0.5 < t < 0.6 */

setfield /kinetics/CaReg/CaStore slave_enable 4

/* Apply fastdt */
setclock 0 {fastdt}
setclock 1 {fastdt}
MAXTIME =   0.2
step {MAXTIME} -time    /* 0.6 < t < 0.8 */

/* Apply normdt */
setclock 0 {normdt}
setclock 1 {normdt}
MAXTIME =   0.7
step {MAXTIME} -time    /* 0.8 < t < 1.5 */

/* Apply slowdt */
setclock 0 {slowdt}
setclock 1 {slowdt}
MAXTIME =   0.5001
SIMDT = {slowdt}
step {MAXTIME} -time    /* 1.5 < t < 2 */

// save data
        do_save_named_plot /graphs/conc2/Ca.Co {"./simresult/fig4/pathdelfig4F_Ca.plot"}

setfield /kinetics/CaReg/CaStore slave_enable 0
reset



// Control Ca2+ time course

echo ""
echo "Control Ca2+ time course"

setclock 0 {normdt}
setclock 1 {normdt}
setclock 3 {plotdt}
MAXTIME = 2.0001
step {MAXTIME} -time

// save data
        do_save_named_plot /graphs/conc2/Ca.Co {"./simresult/fig4/pathdelcontrol_Ca.plot"}



echo "Simulation has done!"
echo "Type 'quit' to exit GENESIS/kinetikit"



