//genesis
// This simulation generates trajectories of Ca2+ and inactivated IP3Rs
// when IP3 step-up pulse and transient Ca2+ infulx are applied.

include DoiCaModel.g       /* main scripts */

float normdt = 1e-06  /* 0 < t < 0.1, 0.51 < t < 2 */
float fastdt = 1e-08  /* 0.5 < t < 0.51            */ 
float slowdt = 1e-05  /* 0.1 < t < 0.5, 2 < t < 10 */
float plotdt = 0.0001
float IP3conc = 0.1   /* default value */

setfield /kinetics/mGluR/100Hz5Glu is_running 0 /* remove mGluR pathway */
setfield /kinetics/Influx/100Hz5PFCa-in kf 0    /* remove AMPAR pathway */
setfield /kinetics/Influx/CF input -200         /* eliminate CF input */


function makedynamics (nowIP3, transres, nowCFkf)
        float nowIP3
	int   transres
        int   nowCFkf 
        str   Cafullname
        str   IP3Rinactfullname

        /* Equilibrium at the basal state for 0.5 sec */
        /* initialze */
        setfield /kinetics/PLC/IP3_PSD CoInit 0.1
        setfield /kinetics/IP3deg/IP3_spine CoInit 0.1
        setfield /kinetics/Influx/CF_pool CoInit 0
        setfield /kinetics/Influx/CF-in kf 0
        setfield /kinetics/PLC/IP3_PSD slave_enable 0
        setfield /kinetics/IP3deg/IP3_spine slave_enable 0
        setfield /kinetics/Influx/CF_pool slave_enable 0

        reset 
        setclock 0 {normdt}
        setclock 1 {normdt}
        setclock 3 {plotdt}
        MAXTIME = 0.1
        step {MAXTIME} -time   /* 0 < t < 0.1 */

        setclock 0 {slowdt}
        setclock 1 {slowdt}
        setclock 3 {plotdt}
        MAXTIME = 0.4
        step {MAXTIME} -time   /* 0.1 < t < 0.5 */


        /* Change [IP3] and Start Ca2+ entry */
        setfield /kinetics/PLC/IP3_PSD CoInit {nowIP3}
        setfield /kinetics/IP3deg/IP3_spine CoInit {nowIP3}
        setfield /kinetics/Influx/CF_pool CoInit 10
        setfield /kinetics/Influx/CF-in kf {nowCFkf}
        setfield /kinetics/PLC/IP3_PSD slave_enable 4
        setfield /kinetics/IP3deg/IP3_spine slave_enable 4
        setfield /kinetics/Influx/CF_pool slave_enable 4


        setclock 0 {fastdt}
        setclock 1 {fastdt}
        MAXTIME =   0.002       /* Ca2+ entry for 2 msec */
        step {MAXTIME} -time    /* 0.5 < t < 0.502 */


        /* Stop Ca2+ entry */
        setfield /kinetics/Influx/CF_pool CoInit 0
        setclock 0 {fastdt}
        setclock 1 {fastdt}
        MAXTIME =   0.008
        step {MAXTIME} -time    /* 0.502 < t <  0.51 */


        /* Apply normdt */
        setclock 0 {normdt}
        setclock 1 {normdt}
        MAXTIME =   1.49
        step {MAXTIME} -time    /* 0.51 < t < 2 */


        /* Apply slowdt */
        setclock 0 {slowdt}
        setclock 1 {slowdt}
        MAXTIME =   8
        SIMDT = {slowdt}
        step {MAXTIME} -time    /* 2 < t < 10 */


        /* save data */
              Cafullname = {"./simresult/fig8CDE/trajectory_IP3" @ {nowIP3} @ "Ca" @ {transres} @ "_Ca.plot"}
         IP3Rinactfullname = {"./simresult/fig8CDE/trajectory_IP3" @ {nowIP3} @ "Ca" @ {transres} @ "_IP3Rinact.plot"}
        do_save_named_plot /graphs/conc2/Ca.Co            {Cafullname}
        do_save_named_plot /moregraphs/conc3/IP3R_inact.Co   {IP3Rinactfullname}    
        echo "saved at IP3 = " {nowIP3} "and transient Ca2+ response = " {transres}

        reset
end


makedynamics 0.1  0     0
makedynamics 0.1  1  2008
makedynamics 0.1  2  5218
makedynamics 0.1  3  8181
makedynamics 0.1  4 10406
makedynamics 0.1  5 12054
makedynamics 0.1  6 13324
makedynamics 0.1  7 14351
makedynamics 0.1  8 15222
makedynamics 0.1  9 15990
makedynamics 0.1 10 16694
makedynamics 2.5  0     0
makedynamics 2.5  1  1749
makedynamics 2.5  2  4775
makedynamics 2.5  3  7674
makedynamics 2.5  4  9870
makedynamics 2.5  5 11503
makedynamics 2.5  6 12762
makedynamics 2.5  7 13780
makedynamics 2.5  8 14643
makedynamics 2.5  9 15404
makedynamics 2.5 10 16100
makedynamics 10   0     0
makedynamics 10   1  1414
makedynamics 10   2  4359
makedynamics 10   3  7261
makedynamics 10   4  9461
makedynamics 10   5 11096
makedynamics 10   6 12357
makedynamics 10   7 13377
makedynamics 10   8 14241
makedynamics 10   9 15004
makedynamics 10  10 15702


echo "Simulation has done!"
echo "Type 'quit' to exit GENESIS/kinetikit"
