//genesis
// This simulation generates IP3 time course 
// when each value for all of the model parameters is varied.

include DoiCaModel.g


setfield /kinetics/Influx/CF input 100          /* CF input starts at -100 sec */

echo ""
echo "# This simulation generates IP3 time courses"
echo "# when each value for all of the 96 model parameters is varied"
echo "# It takes long time (1 day / Pentium 4 PC) to complete."
echo "#"
echo "# The parameters are numbered from 1 to 96."
echo "# 'paramlist.txt' is a list of parameter numbers, IDs, and names."
echo "# To generate sensitivity analysis for parameters numbered from A to B, type"
echo "# paramsIP3loop A B"
echo "#"
echo "# We recommend you to divide the parameter space and use a PC cluster, "
echo "# with no graphical mode, 'genesis -nox figS2BCDE.g'."
echo ""


function vary_kd(reacobj, ratio, vol, order)
    str    reacobj
    float  ratio
    int    order
    float  vol

    float  kfro = {getfield {reacobj} kf}
    float  kbro = {getfield {reacobj} kb}
    float  kfso = kfro * {pow {vol} {order}}
    float  kbso = kbro

    float  kfsn = kfso * {kfso + kbso} / {kfso + {pow {ratio} {order}} * kbso}
    float  kbsn = {pow {ratio} {order}} * kbso * {kfso + kbso} / {kfso + {pow {ratio} {order}} * kbso}
    float  kfrn = kfsn / {pow {vol} {order}}
    float  kbrn = kbsn

    echo "vary raw kf from" {kfro} "to" {kfrn}
    echo "vary raw kb from" {kbro} "to" {kbrn}

    setfield {reacobj} kf {kfrn}
    setfield {reacobj} kb {kbrn}
end



function vary_param(select_num, ratio)
	int select_num
	float ratio

if	(select_num ==  1)
	setfield /kinetics/mGluR/Glu_bind_mGluR kf {11.111 /1.2 / {ratio}}
	setfield /kinetics/mGluR/Glu_bind_mGluR kb {100.0 / {ratio}}
elif	(select_num ==  2)
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kf {11.111 /1.2 / {ratio}}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kb {100.0 / {ratio}}
elif	(select_num ==  3)
	setfield /kinetics/mGluR/mGluR_bind_Gq kf {2.0 /1.2 / {ratio}}
	setfield /kinetics/mGluR/mGluR_bind_Gq kb {100.0 / {ratio}}
elif	(select_num ==  4)
	setfield /kinetics/mGluR/mGluR-Glu_bind_Gq kf {2.0 /1.2 / {ratio}}
	setfield /kinetics/mGluR/mGluR-Glu_bind_Gq kb {100.0 / {ratio}}
elif	(select_num ==  5)
	setfield /kinetics/mGluR/Basal_ActGq kf {0.0001 / {ratio}}
elif	(select_num ==  6)
	setfield /kinetics/mGluR/Trimerize_Gq kf {6.0 /1.2 / {ratio}}
elif	(select_num ==  7)
	setfield /kinetics/PLC/PLC-PIP2_bind_Ca kf {300.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-PIP2_bind_Ca kb {100.0 / {ratio}}
elif	(select_num ==  8)
	setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kf {900.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kb {30.0 / {ratio}}
elif	(select_num ==  9)
	setfield /kinetics/PLC/PLC-PIP2_bind_Gq kf {800.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-PIP2_bind_Gq kb {40.0 / {ratio}}
elif	(select_num == 10)
	setfield /kinetics/PLC/PLC-PIP2-Ca_bind_Gq kf {1200.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-PIP2-Ca_bind_Gq kb {6.0 / {ratio}}
elif	(select_num == 11)
	setfield /kinetics/PLC/PLC-Ca_bind_Gq kf {1200.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-Ca_bind_Gq kb {6.0 / {ratio}}
elif	(select_num == 12)
	setfield /kinetics/PLC/PLC-Ca_bind_PIP2 kf {1.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-Ca_bind_PIP2 kb {170.0 / {ratio}}
elif	(select_num == 13)
	setfield /kinetics/PLC/PLC-Ca-Gq_bind_PIP2 kf {1.0 /1.2 / {ratio}}
	setfield /kinetics/PLC/PLC-Ca-Gq_bind_PIP2 kb {170.0 / {ratio}}
elif	(select_num == 14)
	setfield /kinetics/IP3deg/IP3K_bind_Ca kf {1111.1 /60 /60 / {ratio}}
	setfield /kinetics/IP3deg/IP3K_bind_Ca kb {100.0 / {ratio}}
elif	(select_num == 15)
	setfield /kinetics/IP3deg/IP3K-2Ca_bind_IP3 kf {100.0 /60 / {ratio}}
	setfield /kinetics/IP3deg/IP3K-2Ca_bind_IP3 kb {80.0 / {ratio}}
elif	(select_num == 16)
	setfield /kinetics/IP3deg/IP5P_bind_IP3 kf {9.0 /60 / {ratio}}
	setfield /kinetics/IP3deg/IP5P_bind_IP3 kb {72.0 / {ratio}}
elif	(select_num == 17)
	setfield /kinetics/IP3R/IP3R_bind_IP3 kf {1000.0 /60 / {ratio}}
	setfield /kinetics/IP3R/IP3R_bind_IP3 kb {25800.0 / {ratio}}
elif	(select_num == 18)
	setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kf {8000.0 /60 / {ratio}}
	setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kb {2000.0 / {ratio}}
elif	(select_num == 19)
	setfield /kinetics/IP3R/IP3R_bind_Ca kf {8.8888 /60 / {ratio}}
	setfield /kinetics/IP3R/IP3R_bind_Ca kb {5.0 / {ratio}}
elif	(select_num == 20)
	setfield /kinetics/IP3R/IP3R-Ca_bind_Ca kf {20.0 /60 / {ratio}}
	setfield /kinetics/IP3R/IP3R-Ca_bind_Ca kb {10.0 / {ratio}}
elif	(select_num == 21)
	setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca kf {40.0 /60 / {ratio}}
	setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca kb {15.0 / {ratio}}
elif	(select_num == 22)
	setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca kf {60.0 /60 / {ratio}}
	setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca kb {20.0 / {ratio}}
elif	(select_num == 23)
	setfield /kinetics/CaReg/IP3R/proto/IP3R/IP3R_Ca_channel perm {450.0 / {ratio}}
elif	(select_num == 24)
	setfield /kinetics/CaReg/SERCA_bind_2Ca kf {17417.0 /60 /60 / {ratio}}
	setfield /kinetics/CaReg/SERCA_bind_2Ca kb {1000.0 / {ratio}}
elif	(select_num == 25)
	setfield /kinetics/CaReg/Ca_Leak_from_ER/Ca_Leak_chan_from_ER perm {15.0 / {ratio}}
elif	(select_num == 26)
	setfield /kinetics/CaReg/PMCA_bind_Ca kf {25000.0 /60 / {ratio}}
	setfield /kinetics/CaReg/PMCA_bind_Ca kb {2000.0 / {ratio}}
elif	(select_num == 27)
	setfield /kinetics/CaReg/NCX_bind_2Ca kf {93.827 /60 /60 / {ratio}}
	setfield /kinetics/CaReg/NCX_bind_2Ca kb {4000.0 / {ratio}}
elif	(select_num == 28)
	setfield /kinetics/CaReg/Ca_Leak_from_ext/Ca_Leak_chan_from_ext perm {10.0 / {ratio}}
elif	(select_num == 29)
	setfield /kinetics/CaReg/Ca_bind_calreticulin kf {0.1 /12 / {ratio}}
	setfield /kinetics/CaReg/Ca_bind_calreticulin kb {200.0 / {ratio}}
elif	(select_num == 30)
	setfield /kinetics/CaBuf/Ca_bind_MgGreen kf {1000.0 /60 / {ratio}}
	setfield /kinetics/CaBuf/Ca_bind_MgGreen kb {19000.0 / {ratio}}
elif	(select_num == 31)
	setfield /kinetics/CaBuf/PV_bind_Ca kf {18.5 /60 / {ratio}}
	setfield /kinetics/CaBuf/PV_bind_Ca kb {0.95 / {ratio}}
elif	(select_num == 32)
	setfield /kinetics/CaBuf/CB_bind_2Ca kf {87.0 /60 /60 / {ratio}}
	setfield /kinetics/CaBuf/CB_bind_2Ca kb {11.275 / {ratio}}
elif	(select_num == 33)
	setfield /kinetics/CaBuf/LAB_bind_Ca kf {10.0 /60 / {ratio}}
	setfield /kinetics/CaBuf/LAB_bind_Ca kb {1000.0 / {ratio}}
elif	(select_num == 34)
	setfield /kinetics/CaBuf/LAB2_bind_2Ca kf {10.0 /60 /60 / {ratio}}
	setfield /kinetics/CaBuf/LAB2_bind_2Ca kb {4000.0 / {ratio}}

elif	(select_num == 35)
	vary_kd "/kinetics/mGluR/Glu_bind_mGluR" {ratio} 1.2 1
elif	(select_num == 36)
	vary_kd "/kinetics/mGluR/Glu_bind_mGluR-Gq" {ratio} 1.2 1
elif	(select_num == 37)
	vary_kd "/kinetics/mGluR/mGluR_bind_Gq" {ratio} 1.2 1
elif	(select_num == 38)
	vary_kd "/kinetics/mGluR/mGluR-Glu_bind_Gq" {ratio} 1.2 1
elif	(select_num == 39)
	vary_kd "/kinetics/PLC/PLC-PIP2_bind_Ca" {ratio} 1.2 1
elif	(select_num == 40)
	vary_kd "/kinetics/PLC/PLC-PIP2-Gq_bind_Ca" {ratio} 1.2 1
elif	(select_num == 41)
	vary_kd "/kinetics/PLC/PLC-PIP2_bind_Gq" {ratio} 1.2 1
elif	(select_num == 42)
	vary_kd "/kinetics/PLC/PLC-PIP2-Ca_bind_Gq" {ratio} 1.2 1
elif	(select_num == 43)
	vary_kd "/kinetics/PLC/PLC-Ca_bind_Gq" {ratio} 1.2 1
elif	(select_num == 44)
	vary_kd "/kinetics/PLC/PLC-Ca_bind_PIP2" {ratio} 1.2 1
elif	(select_num == 45)
	vary_kd "/kinetics/PLC/PLC-Ca-Gq_bind_PIP2" {ratio} 1.2 1
elif	(select_num == 46)
	vary_kd "/kinetics/IP3deg/IP3K_bind_Ca" {ratio} 60.0 2
elif	(select_num == 47)
	vary_kd "/kinetics/IP3deg/IP3K-2Ca_bind_IP3" {ratio} 60.0 1
elif	(select_num == 48)
	vary_kd "/kinetics/IP3deg/IP5P_bind_IP3" {ratio} 60.0 1
elif	(select_num == 49)
	vary_kd "/kinetics/IP3R/IP3R_bind_IP3" {ratio} 60.0 1
elif	(select_num == 50)
	vary_kd "/kinetics/IP3R/IP3R-IP3_bind_Ca" {ratio} 60.0 1
elif	(select_num == 51)
	vary_kd "/kinetics/IP3R/IP3R_bind_Ca" {ratio} 60.0 1
elif	(select_num == 52)
	vary_kd "/kinetics/IP3R/IP3R-Ca_bind_Ca" {ratio} 60.0 1
elif	(select_num == 53)
	vary_kd "/kinetics/IP3R/IP3R-2Ca_bind_Ca" {ratio} 60.0 1
elif	(select_num == 54)
	vary_kd "/kinetics/IP3R/IP3R-3Ca_bind_Ca" {ratio} 60.0 1
elif	(select_num == 55)
	vary_kd "/kinetics/CaReg/SERCA_bind_2Ca" {ratio} 60.0 2
elif	(select_num == 56)
	vary_kd "/kinetics/CaReg/PMCA_bind_Ca" {ratio} 60.0 1
elif	(select_num == 57)
	vary_kd "/kinetics/CaReg/NCX_bind_2Ca" {ratio} 60.0 2
elif	(select_num == 58)
	vary_kd "/kinetics/CaReg/Ca_bind_calreticulin" {ratio} 12.0 1
elif	(select_num == 59)
	vary_kd "/kinetics/CaBuf/Ca_bind_MgGreen" {ratio} 60.0 1
elif	(select_num == 60)
	vary_kd "/kinetics/CaBuf/PV_bind_Ca" {ratio} 60.0 1
elif	(select_num == 61)
	vary_kd "/kinetics/CaBuf/CB_bind_2Ca" {ratio} 60.0 2
elif	(select_num == 62)
	vary_kd "/kinetics/CaBuf/LAB_bind_Ca" {ratio} 60.0 1
elif	(select_num == 63)
	vary_kd "/kinetics/CaBuf/LAB2_bind_2Ca" {ratio} 60.0 2

elif	(select_num == 64)
	setfield /kinetics/mGluR/Activate_Gq kf {116.0 * {ratio}}
elif	(select_num == 65)
        setfield /kinetics/mGluR/Inact_Gq kf {0.02 * {ratio}}
elif	(select_num == 66)
	setfield /kinetics/PLC/IP3_prd_without_Gq kf {2.0 * {ratio}}
elif	(select_num == 67)
	setfield /kinetics/PLC/IP3_prd_with_Gq kf {160.0 * {ratio}}
elif	(select_num == 68)
	setfield /kinetics/PLC/inact_Gq_by_PLC-PIP2 kf {8.0 * {ratio}}
elif	(select_num == 69)
	setfield /kinetics/PLC/inact_Gq_by_PLC-PIP2-Ca kf {8.0 * {ratio}}
elif	(select_num == 70)
	setfield /kinetics/PLC/inact_Gq_by_PLC-Ca kf {8.0 * {ratio}}
elif	(select_num == 71)
	setfield /kinetics/IP3deg/IP3K_deg_IP3 kf {20.0 * {ratio}}
elif	(select_num == 72)
	setfield /kinetics/IP3deg/IP5P_deg_IP3 kf {18.0 * {ratio}}
elif	(select_num == 73)
	setfield /kinetics/CaReg/SERCA_uptake kf {250.0 * {ratio}}
elif	(select_num == 74)
	setfield /kinetics/CaReg/PMCA_uptake kf {500.0 * {ratio}}
elif	(select_num == 75)
	setfield /kinetics/CaReg/NCX_uptake kf {1000.0 * {ratio}}

elif	(select_num == 76) /* Glu */
	setfield /kinetics/mGluR/Glu_bind_mGluR kf {11.111 /1.2 * {ratio}}
        setfield /kinetics/mGluR/Glu_bind_mGluR kb {100.0 * {ratio}}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kf {11.111 /1.2 * {ratio}}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kb {100.0 * {ratio}}
elif	(select_num == 77) /* mGluR */
	if	(ratio == 2.0)
	setfield /kinetics/mGluR/mGluR    nInit   {15}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {21}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {45}
	setfield /kinetics/mGluR/mGluR    n       {15}
	setfield /kinetics/mGluR/mGluR-Gq n       {21}
	setfield /kinetics/mGluR/Gq-GDP   n       {45}
	elif	(ratio == 5.0)
	setfield /kinetics/mGluR/mGluR    nInit   {60}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {30}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {30}
	setfield /kinetics/mGluR/mGluR    n       {60}
	setfield /kinetics/mGluR/mGluR-Gq n       {30}
	setfield /kinetics/mGluR/Gq-GDP   n       {30}
	elif	(ratio == 10.0)
	setfield /kinetics/mGluR/mGluR    nInit  {138}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {42}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {18}
	setfield /kinetics/mGluR/mGluR    n      {138}
	setfield /kinetics/mGluR/mGluR-Gq n       {42}
	setfield /kinetics/mGluR/Gq-GDP   n       {18}
	elif	(ratio == 20.0)
	setfield /kinetics/mGluR/mGluR    nInit  {310}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {50}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {10}
	setfield /kinetics/mGluR/mGluR    n      {310}
	setfield /kinetics/mGluR/mGluR-Gq n       {50}
	setfield /kinetics/mGluR/Gq-GDP   n       {10}
	elif	(ratio == 50.0)
	setfield /kinetics/mGluR/mGluR    nInit  {844}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {56}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {4}
	setfield /kinetics/mGluR/mGluR    n      {844}
	setfield /kinetics/mGluR/mGluR-Gq n       {56}
	setfield /kinetics/mGluR/Gq-GDP   n        {4}
	elif	(ratio == 100.0)
	setfield /kinetics/mGluR/mGluR    nInit {1742}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {58}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {2}
	setfield /kinetics/mGluR/mGluR    n     {1742}
	setfield /kinetics/mGluR/mGluR-Gq n       {58}
	setfield /kinetics/mGluR/Gq-GDP   n        {2}
	elif	(ratio == 0.5)
	setfield /kinetics/mGluR/mGluR    nInit    {5}
	setfield /kinetics/mGluR/mGluR-Gq nInit    {4}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {56}
	setfield /kinetics/mGluR/mGluR    n        {5}
	setfield /kinetics/mGluR/mGluR-Gq n        {4}
	setfield /kinetics/mGluR/Gq-GDP   n       {56}
	elif	(ratio == 0.2)
	setfield /kinetics/mGluR/mGluR    nInit  {1.8}
	setfield /kinetics/mGluR/mGluR-Gq nInit  {1.8}
	setfield /kinetics/mGluR/Gq-GDP   nInit {58.2}
	setfield /kinetics/mGluR/mGluR    n      {1.8}
	setfield /kinetics/mGluR/mGluR-Gq n      {1.8}
	setfield /kinetics/mGluR/Gq-GDP   n     {58.2}
	elif	(ratio == 0.1)
	setfield /kinetics/mGluR/mGluR    nInit  {0.9}
	setfield /kinetics/mGluR/mGluR-Gq nInit  {0.9}
	setfield /kinetics/mGluR/Gq-GDP   nInit {59.1}
	setfield /kinetics/mGluR/mGluR    n      {0.9}
	setfield /kinetics/mGluR/mGluR-Gq n      {0.9}
	setfield /kinetics/mGluR/Gq-GDP   n     {59.1}
	elif	(ratio == 0.05)
	setfield /kinetics/mGluR/mGluR    nInit  {0.45}
	setfield /kinetics/mGluR/mGluR-Gq nInit  {0.45}
	setfield /kinetics/mGluR/Gq-GDP   nInit {59.55}
	setfield /kinetics/mGluR/mGluR    n      {0.45}
	setfield /kinetics/mGluR/mGluR-Gq n      {0.45}
	setfield /kinetics/mGluR/Gq-GDP   n     {59.55}
	elif	(ratio == 0.02)
	setfield /kinetics/mGluR/mGluR    nInit  {0.18}
	setfield /kinetics/mGluR/mGluR-Gq nInit  {0.18}
	setfield /kinetics/mGluR/Gq-GDP   nInit {59.82}
	setfield /kinetics/mGluR/mGluR    n      {0.18}
	setfield /kinetics/mGluR/mGluR-Gq n      {0.18}
	setfield /kinetics/mGluR/Gq-GDP   n     {59.82}
	elif	(ratio == 0.01)
	setfield /kinetics/mGluR/mGluR    nInit  {0.09}
	setfield /kinetics/mGluR/mGluR-Gq nInit  {0.09}
	setfield /kinetics/mGluR/Gq-GDP   nInit {59.91}
	setfield /kinetics/mGluR/mGluR    n      {0.09}
	setfield /kinetics/mGluR/mGluR-Gq n      {0.09}
	setfield /kinetics/mGluR/Gq-GDP   n     {59.91}
	end
elif	(select_num == 78) /* Gq */
	if	(ratio == 2.0)
	setfield /kinetics/mGluR/mGluR    nInit    {6.5}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {11.5}
	setfield /kinetics/mGluR/Gq-GDP   nInit  {108.5}
	setfield /kinetics/mGluR/mGluR    n        {6.5}
	setfield /kinetics/mGluR/mGluR-Gq n       {11.5}
	setfield /kinetics/mGluR/Gq-GDP   n      {108.5}
	elif	(ratio == 5.0)
	setfield /kinetics/mGluR/mGluR    nInit      {3}
	setfield /kinetics/mGluR/mGluR-Gq nInit     {15}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {285}
	setfield /kinetics/mGluR/mGluR    n          {3}
	setfield /kinetics/mGluR/mGluR-Gq n         {15}
	setfield /kinetics/mGluR/Gq-GDP   n        {285}
	elif	(ratio == 10.0)
	setfield /kinetics/mGluR/mGluR    nInit    {1.5}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {16.5}
	setfield /kinetics/mGluR/Gq-GDP   nInit  {583.5}
	setfield /kinetics/mGluR/mGluR    n        {1.5}
	setfield /kinetics/mGluR/mGluR-Gq n       {16.5}
	setfield /kinetics/mGluR/Gq-GDP   n      {583.5}
	elif	(ratio == 20.0)
	setfield /kinetics/mGluR/mGluR    nInit      {1}
	setfield /kinetics/mGluR/mGluR-Gq nInit     {17}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {1182}
	setfield /kinetics/mGluR/mGluR    n          {1}
	setfield /kinetics/mGluR/mGluR-Gq n         {17}
	setfield /kinetics/mGluR/Gq-GDP   n       {1182}
	elif	(ratio == 50.0)
	setfield /kinetics/mGluR/mGluR    nInit    {0.5}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {17.5}
	setfield /kinetics/mGluR/Gq-GDP   nInit {2982.5}
	setfield /kinetics/mGluR/mGluR    n        {0.5}
	setfield /kinetics/mGluR/mGluR-Gq n       {17.5}
	setfield /kinetics/mGluR/Gq-GDP   n     {2982.5}
	elif	(ratio == 100.0)
	setfield /kinetics/mGluR/mGluR    nInit    {0.2}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {17.8}
	setfield /kinetics/mGluR/Gq-GDP   nInit {5982.2}
	setfield /kinetics/mGluR/mGluR    n        {0.2}
	setfield /kinetics/mGluR/mGluR-Gq n       {17.8}
	setfield /kinetics/mGluR/Gq-GDP   n     {5982.2}
	elif	(ratio == 0.5)
	setfield /kinetics/mGluR/mGluR    nInit     {13}
	setfield /kinetics/mGluR/mGluR-Gq nInit      {5}
	setfield /kinetics/mGluR/Gq-GDP   nInit     {25}
	setfield /kinetics/mGluR/mGluR    n         {13}
	setfield /kinetics/mGluR/mGluR-Gq n          {5}
	setfield /kinetics/mGluR/Gq-GDP   n         {25}
	elif	(ratio == 0.2)
	setfield /kinetics/mGluR/mGluR    nInit   {15.5}
	setfield /kinetics/mGluR/mGluR-Gq nInit    {2.5}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {9.5}
	setfield /kinetics/mGluR/mGluR    n       {15.5}
	setfield /kinetics/mGluR/mGluR-Gq n        {2.5}
	setfield /kinetics/mGluR/Gq-GDP   n        {9.5}
	elif	(ratio == 0.1)
	setfield /kinetics/mGluR/mGluR    nInit   {16.5}
	setfield /kinetics/mGluR/mGluR-Gq nInit    {1.5}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {4.5}
	setfield /kinetics/mGluR/mGluR    n       {16.5}
	setfield /kinetics/mGluR/mGluR-Gq n        {1.5}
	setfield /kinetics/mGluR/Gq-GDP   n        {4.5}
	elif	(ratio == 0.05)
	setfield /kinetics/mGluR/mGluR    nInit   {17.3}
	setfield /kinetics/mGluR/mGluR-Gq nInit    {0.7}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {2.3}
	setfield /kinetics/mGluR/mGluR    n       {17.3}
	setfield /kinetics/mGluR/mGluR-Gq n        {0.7}
	setfield /kinetics/mGluR/Gq-GDP   n        {2.3}
	elif	(ratio == 0.02)
	setfield /kinetics/mGluR/mGluR    nInit   {17.7}
	setfield /kinetics/mGluR/mGluR-Gq nInit    {0.3}
	setfield /kinetics/mGluR/Gq-GDP   nInit    {0.9}
	setfield /kinetics/mGluR/mGluR    n       {17.7}
	setfield /kinetics/mGluR/mGluR-Gq n        {0.3}
	setfield /kinetics/mGluR/Gq-GDP   n        {0.9}
	elif	(ratio == 0.01)
	setfield /kinetics/mGluR/mGluR    nInit  {17.86}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {0.14}
	setfield /kinetics/mGluR/Gq-GDP   nInit   {0.46}
	setfield /kinetics/mGluR/mGluR    n      {17.86}
	setfield /kinetics/mGluR/mGluR-Gq n       {0.14}
	setfield /kinetics/mGluR/Gq-GDP   n       {0.46}
	end
elif	(select_num == 79) /* PIP2 */
	if	(ratio == 2.0)
	setfield /kinetics/PLC/PIP2        nInit  {10000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {42.51}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.34}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.15}
	setfield /kinetics/PLC/PIP2        n      {10000}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.51}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.34}
	setfield /kinetics/PLC/PLC-Ca      n       {0.15}
	elif	(ratio == 5.0)
	setfield /kinetics/PLC/PIP2        nInit  {25000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {42.58}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.36}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.06}
	setfield /kinetics/PLC/PIP2        n      {25000}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.58}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.36}
	setfield /kinetics/PLC/PLC-Ca      n       {0.06}
	elif	(ratio == 10.0)
	setfield /kinetics/PLC/PIP2        nInit  {50000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {42.61}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.36}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.03}
	setfield /kinetics/PLC/PIP2        n      {50000}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.61}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.36}
	setfield /kinetics/PLC/PLC-Ca      n       {0.03}
	elif	(ratio == 20.0)
	setfield /kinetics/PLC/PIP2        nInit {100000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {42.62}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.36}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.02}
	setfield /kinetics/PLC/PIP2        n     {100000}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.62}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.36}
	setfield /kinetics/PLC/PLC-Ca      n       {0.02}
	elif	(ratio == 50.0)
	setfield /kinetics/PLC/PIP2        nInit {200000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {42.63}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.36}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.01}
	setfield /kinetics/PLC/PIP2        n     {200000}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.63}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.36}
	setfield /kinetics/PLC/PLC-Ca      n       {0.01}
	elif	(ratio == 100.0)
	setfield /kinetics/PLC/PIP2        nInit {500000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {42.64}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.36}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.0}
	setfield /kinetics/PLC/PIP2        n     {500000}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.64}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.36}
	setfield /kinetics/PLC/PLC-Ca      n       {0.0}
	elif	(ratio == 0.5)
	setfield /kinetics/PLC/PIP2        nInit  {2500}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {41.1}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.3}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.6}
	setfield /kinetics/PLC/PIP2        n      {2500}
	setfield /kinetics/PLC/PLC-PIP2    n      {42.1}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.3}
	setfield /kinetics/PLC/PLC-Ca      n       {0.6}
	elif	(ratio == 0.2)
	setfield /kinetics/PLC/PIP2        nInit  {1000}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {41.4}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.1}
	setfield /kinetics/PLC/PLC-Ca      nInit   {1.5}
	setfield /kinetics/PLC/PIP2        n      {1000}
	setfield /kinetics/PLC/PLC-PIP2    n      {41.4}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.1}
	setfield /kinetics/PLC/PLC-Ca      n       {1.5}
	elif	(ratio == 0.1)
	setfield /kinetics/PLC/PIP2        nInit   {500}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {40.2}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {6.9}
	setfield /kinetics/PLC/PLC-Ca      nInit   {2.9}
	setfield /kinetics/PLC/PIP2        n       {500}
	setfield /kinetics/PLC/PLC-PIP2    n      {40.2}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {6.9}
	setfield /kinetics/PLC/PLC-Ca      n       {2.9}
	elif	(ratio == 0.05)
	setfield /kinetics/PLC/PIP2        nInit   {250}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {38.1}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {6.5}
	setfield /kinetics/PLC/PLC-Ca      nInit   {5.4}
	setfield /kinetics/PLC/PIP2        n       {250}
	setfield /kinetics/PLC/PLC-PIP2    n      {38.1}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {6.5}
	setfield /kinetics/PLC/PLC-Ca      n       {5.4}
	elif	(ratio == 0.02)
	setfield /kinetics/PLC/PIP2        nInit   {100}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {32.8}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {5.6}
	setfield /kinetics/PLC/PLC-Ca      nInit  {11.6}
	setfield /kinetics/PLC/PIP2        n       {100}
	setfield /kinetics/PLC/PLC-PIP2    n      {32.8}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {5.6}
	setfield /kinetics/PLC/PLC-Ca      n      {11.6}
	elif	(ratio == 0.01)
	setfield /kinetics/PLC/PIP2        nInit    {50}
	setfield /kinetics/PLC/PLC-PIP2    nInit  {26.7}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {4.5}
	setfield /kinetics/PLC/PLC-Ca      nInit  {18.8}
	setfield /kinetics/PLC/PIP2        n        {50}
	setfield /kinetics/PLC/PLC-PIP2    n      {26.7}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {4.5}
	setfield /kinetics/PLC/PLC-Ca      n      {18.8}
	end
elif	(select_num == 80) /* PLC */
	setfield /kinetics/PLC/PLC-PIP2    nInit   {42 * {ratio}}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.5 * {ratio}}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.5 * {ratio}}
	setfield /kinetics/PLC/PLC-PIP2    n       {42 * {ratio}}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.5 * {ratio}}
	setfield /kinetics/PLC/PLC-Ca      n       {0.5 * {ratio}}
elif	(select_num == 81) /* IP3 */
	if	(ratio == 2.0)
	setfield /kinetics/PLC/IP3_PSD              n {0.24}
	setfield /kinetics/IP3deg/IP3_spine         n {12}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {58.8}
	setfield /kinetics/IP3deg/IP5P-IP3          n {1.2}
	elif	(ratio == 5.0)
	setfield /kinetics/PLC/IP3_PSD              n {0.6}
	setfield /kinetics/IP3deg/IP3_spine         n {30}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {57.1}
	setfield /kinetics/IP3deg/IP5P-IP3          n {2.9}
	elif	(ratio == 10.0)
	setfield /kinetics/PLC/IP3_PSD              n {1.2}
	setfield /kinetics/IP3deg/IP3_spine         n {60}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {54.5}
	setfield /kinetics/IP3deg/IP5P-IP3          n {4.5}
	elif	(ratio == 20.0)
	setfield /kinetics/PLC/IP3_PSD              n {2.4}
	setfield /kinetics/IP3deg/IP3_spine         n {120}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {50}
	setfield /kinetics/IP3deg/IP5P-IP3          n {10}
	elif	(ratio == 50.0)
	setfield /kinetics/PLC/IP3_PSD              n {6.0}
	setfield /kinetics/IP3deg/IP3_spine         n {240}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {40}
	setfield /kinetics/IP3deg/IP5P-IP3          n {20}
	elif	(ratio == 100.0)
	setfield /kinetics/PLC/IP3_PSD              n {12.0}
	setfield /kinetics/IP3deg/IP3_spine         n {480}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {30}
	setfield /kinetics/IP3deg/IP5P-IP3          n {30}
	elif	(ratio == 0.5)
	setfield /kinetics/PLC/IP3_PSD              n {0.06}
	setfield /kinetics/IP3deg/IP3_spine         n {3}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {59.7}
	setfield /kinetics/IP3deg/IP5P-IP3          n {0.3}
	elif	(ratio == 0.2)
	setfield /kinetics/PLC/IP3_PSD              n {0.024}
	setfield /kinetics/IP3deg/IP3_spine         n {1.2}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {59.8}
	setfield /kinetics/IP3deg/IP5P-IP3          n {0.2}
	elif	(ratio == 0.1)
	setfield /kinetics/PLC/IP3_PSD              n {0.012}
	setfield /kinetics/IP3deg/IP3_spine         n {0.6}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {59.9}
	setfield /kinetics/IP3deg/IP5P-IP3          n {0.1}
	elif	(ratio == 0.05)
	setfield /kinetics/PLC/IP3_PSD              n {0.0006}
	setfield /kinetics/IP3deg/IP3_spine         n {0.3}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {60}
	setfield /kinetics/IP3deg/IP5P-IP3          n  {0}
	elif	(ratio == 0.02)
	setfield /kinetics/PLC/IP3_PSD              n {0.00024}
	setfield /kinetics/IP3deg/IP3_spine         n {0.12}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {60}
	setfield /kinetics/IP3deg/IP5P-IP3          n  {0}
	elif	(ratio == 0.01)
	setfield /kinetics/PLC/IP3_PSD              n {0.0012}
	setfield /kinetics/IP3deg/IP3_spine         n {0.06}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {60}
	setfield /kinetics/IP3deg/IP5P-IP3          n  {0}
	end
elif	(select_num == 82) /* IP3 3-kinase */
	setfield /kinetics/IP3deg/IP3_3-kinase nInit  {52 * {ratio}}
	setfield /kinetics/IP3deg/IP3K-2Ca     nInit   {2 * {ratio}}
	setfield /kinetics/IP3deg/IP3_3-kinase n      {52 * {ratio}}
	setfield /kinetics/IP3deg/IP3K-2Ca     n       {2 * {ratio}}
elif	(select_num == 83) /* IP3 5-phosphatase */
	setfield /kinetics/IP3deg/IP3_5-phosphatase nInit  {58.8 * {ratio}}
	setfield /kinetics/IP3deg/IP5P-IP3          nInit   {1.2 * {ratio}}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n      {58.8 * {ratio}}
	setfield /kinetics/IP3deg/IP5P-IP3          n       {1.2 * {ratio}}
elif	(select_num == 84) /* IP3R */
	setfield /kinetics/IP3R/IP3Rec    nInit {14.22  * {ratio}}
	setfield /kinetics/IP3R/IP3R-IP3  nInit  {0.06 * {ratio}}
	setfield /kinetics/IP3R/IP3R_open nInit  {0.01 * {ratio}}
	setfield /kinetics/IP3R/IP3R-Ca   nInit  {1.5 * {ratio}}
	setfield /kinetics/IP3R/IP3R-2Ca  nInit  {0.18 * {ratio}}
	setfield /kinetics/IP3R/IP3R-3Ca  nInit  {0.03 * {ratio}}
	setfield /kinetics/IP3R/IP3R-4Ca  nInit  {0.0 * {ratio}}
	setfield /kinetics/IP3R/IP3Rec    n     {14.22 * {ratio}}
	setfield /kinetics/IP3R/IP3R-IP3  n      {0.06 * {ratio}}
	setfield /kinetics/IP3R/IP3R_open n      {0.01 * {ratio}}
	setfield /kinetics/IP3R/IP3R-Ca   n      {1.5 * {ratio}}
	setfield /kinetics/IP3R/IP3R-2Ca  n      {0.18 * {ratio}}
	setfield /kinetics/IP3R/IP3R-3Ca  n      {0.03 * {ratio}}
	setfield /kinetics/IP3R/IP3R-4Ca  n      {0.0 * {ratio}}
elif	(select_num == 85) /* [Ca2+]i */
	if	(ratio == 2.0)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {7.2}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.144}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {46}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {8}
	setfield /kinetics/PLC/PLC-PIP2                n {36.4}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {13.1}
	setfield /kinetics/PLC/PLC-Ca                  n {0.5}
	setfield /kinetics/CaReg/SERCA                 n {129}
	setfield /kinetics/CaReg/SERCA-2Ca             n {26}
	setfield /kinetics/CaReg/PMCA                  n {49}
	setfield /kinetics/CaReg/PMCA-Ca               n {59}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14906}
	setfield /kinetics/CaBuf/MgGreen*              n {94}
	setfield /kinetics/CaBuf/parvalbumin           n {899}
	setfield /kinetics/CaBuf/PV-Ca                 n {2101}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5400}
	setfield /kinetics/CaBuf/CB-2Ca                n {600}
	setfield /kinetics/CaBuf/LowAffBuf             n {5993}
	setfield /kinetics/CaBuf/LAB-Ca                n {7}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	elif	(ratio == 5.0)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {18}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.36}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {27}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {27}
	setfield /kinetics/PLC/PLC-PIP2                n {25.8}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {23.2}
	setfield /kinetics/PLC/PLC-Ca                  n {1.0}
	setfield /kinetics/CaReg/SERCA                 n {69}
	setfield /kinetics/CaReg/SERCA-2Ca             n {86}
	setfield /kinetics/CaReg/PMCA                  n {27}
	setfield /kinetics/CaReg/PMCA-Ca               n {81}
	setfield /kinetics/CaReg/NCX                   n {31.9}
	setfield /kinetics/CaReg/NCX-2Ca               n {0.1}
	setfield /kinetics/CaBuf/MgGreen               n {14767}
	setfield /kinetics/CaBuf/MgGreen*              n {233}
	setfield /kinetics/CaBuf/parvalbumin           n {438}
	setfield /kinetics/CaBuf/PV-Ca                 n {2562}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {3541}
	setfield /kinetics/CaBuf/CB-2Ca                n {2559}
	setfield /kinetics/CaBuf/LowAffBuf             n {5982}
	setfield /kinetics/CaBuf/LAB-Ca                n {18}
	setfield /kinetics/CaBuf/LowAffBuf2            n {5999}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {1}
	elif	(ratio == 10.0)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {36}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.72}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {11}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {43}
	setfield /kinetics/PLC/PLC-PIP2                n {17.4}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {31.3}
	setfield /kinetics/PLC/PLC-Ca                  n {1.3}
	setfield /kinetics/CaReg/SERCA                 n {26}
	setfield /kinetics/CaReg/SERCA-2Ca             n {129}
	setfield /kinetics/CaReg/PMCA                  n {15}
	setfield /kinetics/CaReg/PMCA-Ca               n {93}
	setfield /kinetics/CaReg/NCX                   n {31.8}
	setfield /kinetics/CaReg/NCX-2Ca               n {0.2}
	setfield /kinetics/CaBuf/MgGreen               n {14541}
	setfield /kinetics/CaBuf/MgGreen*              n {459}
	setfield /kinetics/CaBuf/parvalbumin           n {237}
	setfield /kinetics/CaBuf/PV-Ca                 n {2763}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {1588}
	setfield /kinetics/CaBuf/CB-2Ca                n {4412}
	setfield /kinetics/CaBuf/LowAffBuf             n {5964}
	setfield /kinetics/CaBuf/LAB-Ca                n {36}
	setfield /kinetics/CaBuf/LowAffBuf2            n {5995}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {5}
	elif	(ratio == 20.0)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {72}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {1.44}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {3}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {51}
	setfield /kinetics/PLC/PLC-PIP2                n {10.5}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {37.9}
	setfield /kinetics/PLC/PLC-Ca                  n {1.6}
	setfield /kinetics/CaReg/SERCA                 n {7}
	setfield /kinetics/CaReg/SERCA-2Ca             n {148}
	setfield /kinetics/CaReg/NCX                   n {31.2}
	setfield /kinetics/CaReg/NCX-2Ca               n {0.8}
	setfield /kinetics/CaReg/PMCA                  n {8}
	setfield /kinetics/CaReg/PMCA-Ca               n {100}
	setfield /kinetics/CaBuf/MgGreen               n {14109}
	setfield /kinetics/CaBuf/MgGreen*              n {891}
	setfield /kinetics/CaBuf/parvalbumin           n {123}
	setfield /kinetics/CaBuf/PV-Ca                 n {2877}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {495}
	setfield /kinetics/CaBuf/CB-2Ca                n {5505}
	setfield /kinetics/CaBuf/LowAffBuf             n {5929}
	setfield /kinetics/CaBuf/LAB-Ca                n {71}
	setfield /kinetics/CaBuf/LowAffBuf2            n {5978}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {22}
	elif	(ratio == 50.0)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {180}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {3.6}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {0.5}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {53.5}
	setfield /kinetics/PLC/PLC-PIP2                n {4.8}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {43.4}
	setfield /kinetics/PLC/PLC-Ca                  n {1.8}
	setfield /kinetics/CaReg/SERCA                 n {1}
	setfield /kinetics/CaReg/SERCA-2Ca             n {154}
	setfield /kinetics/CaReg/PMCA                  n {3}
	setfield /kinetics/CaReg/PMCA-Ca               n {105}
	setfield /kinetics/CaReg/NCX                   n {27}
	setfield /kinetics/CaReg/NCX-2Ca               n {5}
	setfield /kinetics/CaBuf/MgGreen               n {14906}
	setfield /kinetics/CaBuf/MgGreen*              n {12955}
	setfield /kinetics/CaBuf/parvalbumin           n {2045}
	setfield /kinetics/CaBuf/PV-Ca                 n {50}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {85}
	setfield /kinetics/CaBuf/CB-2Ca                n {5915}
	setfield /kinetics/CaBuf/LowAffBuf             n {5825}
	setfield /kinetics/CaBuf/LAB-Ca                n {175}
	setfield /kinetics/CaBuf/LowAffBuf2            n {5868}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {132}
	elif	(ratio == 100.0)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {360}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {7.2}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {0}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {54}
	setfield /kinetics/PLC/PLC-PIP2                n {2.5}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {45.6}
	setfield /kinetics/PLC/PLC-Ca                  n {1.9}
	setfield /kinetics/CaReg/SERCA                 n {0}
	setfield /kinetics/CaReg/SERCA-2Ca             n {155}
	setfield /kinetics/CaReg/PMCA                  n {4}
	setfield /kinetics/CaReg/PMCA-Ca               n {108}
	setfield /kinetics/CaReg/NCX                   n {19}
	setfield /kinetics/CaReg/NCX-2Ca               n {13}
	setfield /kinetics/CaBuf/MgGreen               n {11400}
	setfield /kinetics/CaBuf/MgGreen*              n {3600}
	setfield /kinetics/CaBuf/parvalbumin           n {25}
	setfield /kinetics/CaBuf/PV-Ca                 n {2975}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {22}
	setfield /kinetics/CaBuf/CB-2Ca                n {5978}
	setfield /kinetics/CaBuf/LowAffBuf             n {5660}
	setfield /kinetics/CaBuf/LAB-Ca                n {340}
	setfield /kinetics/CaBuf/LowAffBuf2            n {5505}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {495}
	elif	(ratio == 0.5)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {1.8}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.036}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {53.5}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {0.5}
	setfield /kinetics/PLC/PLC-PIP2                n {45.7}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {4.1}
	setfield /kinetics/PLC/PLC-Ca                  n {0.2}
	setfield /kinetics/CaReg/SERCA                 n {153}
	setfield /kinetics/CaReg/SERCA-2Ca             n {2}
	setfield /kinetics/CaReg/PMCA                  n {83}
	setfield /kinetics/CaReg/PMCA-Ca               n {25}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14976}
	setfield /kinetics/CaBuf/MgGreen*              n {24}
	setfield /kinetics/CaBuf/parvalbumin           n {1894}
	setfield /kinetics/CaBuf/PV-Ca                 n {1106}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5959}
	setfield /kinetics/CaBuf/CB-2Ca                n {41}
	setfield /kinetics/CaBuf/LowAffBuf             n {5998}
	setfield /kinetics/CaBuf/LAB-Ca                n {2}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	elif	(ratio == 0.2)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {0.72}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.018}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {53.9}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {0.1}
	setfield /kinetics/PLC/PLC-PIP2                n {48.2}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {1.7}
	setfield /kinetics/PLC/PLC-Ca                  n {0.1}
	setfield /kinetics/CaReg/SERCA                 n {154.7}
	setfield /kinetics/CaReg/SERCA-2Ca             n {0.3}
	setfield /kinetics/CaReg/PMCA                  n {96}
	setfield /kinetics/CaReg/PMCA-Ca               n {12}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14991}
	setfield /kinetics/CaBuf/MgGreen*              n {9}
	setfield /kinetics/CaBuf/parvalbumin           n {2690}
	setfield /kinetics/CaBuf/PV-Ca                 n {310}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5993}
	setfield /kinetics/CaBuf/CB-2Ca                n {7}
	setfield /kinetics/CaBuf/LowAffBuf             n {5999}
	setfield /kinetics/CaBuf/LAB-Ca                n {1}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	elif	(ratio == 0.1)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {0.36}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.0072}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {54}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {0}
	setfield /kinetics/PLC/PLC-PIP2                n {49.1}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {0.9}
	setfield /kinetics/PLC/PLC-Ca                  n {0}
	setfield /kinetics/CaReg/SERCA                 n {154.9}
	setfield /kinetics/CaReg/SERCA-2Ca             n {0.1}
	setfield /kinetics/CaReg/PMCA                  n {102}
	setfield /kinetics/CaReg/PMCA-Ca               n {6}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14995}
	setfield /kinetics/CaBuf/MgGreen*              n {5}
	setfield /kinetics/CaBuf/parvalbumin           n {2684}
	setfield /kinetics/CaBuf/PV-Ca                 n {316}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5998}
	setfield /kinetics/CaBuf/CB-2Ca                n {2}
	setfield /kinetics/CaBuf/LowAffBuf             n {5999.6}
	setfield /kinetics/CaBuf/LAB-Ca                n {0.4}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	elif	(ratio == 0.05)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {0.072}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.00144}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {54}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {0}
	setfield /kinetics/PLC/PLC-PIP2                n {49.5}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {0.5}
	setfield /kinetics/PLC/PLC-Ca                  n {0}
	setfield /kinetics/CaReg/SERCA                 n {155}
	setfield /kinetics/CaReg/SERCA-2Ca             n {0}
	setfield /kinetics/CaReg/PMCA                  n {105}
	setfield /kinetics/CaReg/PMCA-Ca               n {3}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14998}
	setfield /kinetics/CaBuf/MgGreen*              n {2}
	setfield /kinetics/CaBuf/parvalbumin           n {2834}
	setfield /kinetics/CaBuf/PV-Ca                 n {166}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5999.6}
	setfield /kinetics/CaBuf/CB-2Ca                n {0.4}
	setfield /kinetics/CaBuf/LowAffBuf             n {5999.8}
	setfield /kinetics/CaBuf/LAB-Ca                n {0.2}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	elif	(ratio == 0.02)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {0.072}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.00144}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {54}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {0}
	setfield /kinetics/PLC/PLC-PIP2                n {49.8}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {0.2}
	setfield /kinetics/PLC/PLC-Ca                  n {0}
	setfield /kinetics/CaReg/SERCA                 n {155}
	setfield /kinetics/CaReg/SERCA-2Ca             n {0}
	setfield /kinetics/CaReg/PMCA                  n {107}
	setfield /kinetics/CaReg/PMCA-Ca               n {1}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14999}
	setfield /kinetics/CaBuf/MgGreen*              n {1}
	setfield /kinetics/CaBuf/parvalbumin           n {2931}
	setfield /kinetics/CaBuf/PV-Ca                 n {69}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5999.9}
	setfield /kinetics/CaBuf/CB-2Ca                n {0.1}
	setfield /kinetics/CaBuf/LowAffBuf             n {5999.9}
	setfield /kinetics/CaBuf/LAB-Ca                n {0.1}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	elif	(ratio == 0.01)
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {0.0036}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.00072}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {54}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {0}
	setfield /kinetics/PLC/PLC-PIP2                n {49.9}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {0.1}
	setfield /kinetics/PLC/PLC-Ca                  n {0}
	setfield /kinetics/CaReg/SERCA                 n {155}
	setfield /kinetics/CaReg/SERCA-2Ca             n {0}
	setfield /kinetics/CaReg/PMCA                  n {106.4}
	setfield /kinetics/CaReg/PMCA-Ca               n {0.6}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {15000}
	setfield /kinetics/CaBuf/MgGreen*              n {0}
	setfield /kinetics/CaBuf/parvalbumin           n {2965}
	setfield /kinetics/CaBuf/PV-Ca                 n {35}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {6000}
	setfield /kinetics/CaBuf/CB-2Ca                n {0}
	setfield /kinetics/CaBuf/LowAffBuf             n {6000}
	setfield /kinetics/CaBuf/LAB-Ca                n {0}
	setfield /kinetics/CaBuf/LowAffBuf2            n {6000}
	setfield /kinetics/CaBuf/LAB2-2Ca              n {0}
	end
elif	(select_num == 86) /* SERCA */
	setfield /kinetics/CaReg/SERCA     nInit {148 * {ratio}}
	setfield /kinetics/CaReg/SERCA-2Ca nInit {7 * {ratio}}
	setfield /kinetics/CaReg/SERCA     n     {148 * {ratio}}
	setfield /kinetics/CaReg/SERCA-2Ca n     {7 * {ratio}}
elif	(select_num == 87) /* PMCA */
	setfield /kinetics/CaReg/PMCA      nInit {68 * {ratio}}
	setfield /kinetics/CaReg/PMCA-Ca   nInit {40 * {ratio}}
	setfield /kinetics/CaReg/PMCA      n     {68 * {ratio}}
	setfield /kinetics/CaReg/PMCA-Ca   n     {40 * {ratio}}
elif	(select_num == 88) /* Na+/Ca2+ exchanger */
	setfield /kinetics/CaReg/NCX       nInit {32 * {ratio}}
	setfield /kinetics/CaReg/NCX       n     {32 * {ratio}}
elif	(select_num == 89) /* [Ca2+]ER */
	if	(ratio == 2.0)
	setfield /kinetics/CaReg/CaStore         n    {3600}
	setfield /kinetics/CaReg/calreticulin    n  {897390}
	setfield /kinetics/CaReg/calreticulin-Ca n  {134610}
	elif	(ratio == 5.0)
	setfield /kinetics/CaReg/CaStore         n    {9000}
	setfield /kinetics/CaReg/calreticulin    n  {750550}
	setfield /kinetics/CaReg/calreticulin-Ca n  {281450}
	elif	(ratio == 10.0)
	setfield /kinetics/CaReg/CaStore         n   {18000}
	setfield /kinetics/CaReg/calreticulin    n  {589720}
	setfield /kinetics/CaReg/calreticulin-Ca n  {442280}
	elif	(ratio == 20.0)
	setfield /kinetics/CaReg/CaStore         n   {36000}
	setfield /kinetics/CaReg/calreticulin    n  {412800}
	setfield /kinetics/CaReg/calreticulin-Ca n  {619200}
	elif	(ratio == 50.0)
	setfield /kinetics/CaReg/CaStore         n   {90000}
	setfield /kinetics/CaReg/calreticulin    n  {217260}
	setfield /kinetics/CaReg/calreticulin-Ca n  {814740}
	elif	(ratio == 100.0)
	setfield /kinetics/CaReg/CaStore         n  {180000}
	setfield /kinetics/CaReg/calreticulin    n  {121410}
	setfield /kinetics/CaReg/calreticulin-Ca n  {910590}
	elif	(ratio == 0.5)
	setfield /kinetics/CaReg/CaStore         n     {900}
	setfield /kinetics/CaReg/calreticulin    n  {994699}
	setfield /kinetics/CaReg/calreticulin-Ca n   {37301}
	elif	(ratio == 0.2)
	setfield /kinetics/CaReg/CaStore         n     {360}
	setfield /kinetics/CaReg/calreticulin    n {1016749}
	setfield /kinetics/CaReg/calreticulin-Ca n   {15251}
	elif	(ratio == 0.1)
	setfield /kinetics/CaReg/CaStore         n     {180}
	setfield /kinetics/CaReg/calreticulin    n {1024318}
	setfield /kinetics/CaReg/calreticulin-Ca n    {7682}
	elif	(ratio == 0.05)
	setfield /kinetics/CaReg/CaStore         n      {90}
	setfield /kinetics/CaReg/calreticulin    n {1028144}
	setfield /kinetics/CaReg/calreticulin-Ca n    {3856}
	elif	(ratio == 0.02)
	setfield /kinetics/CaReg/CaStore         n      {36}
	setfield /kinetics/CaReg/calreticulin    n {1030454}
	setfield /kinetics/CaReg/calreticulin-Ca n    {1546}
	elif	(ratio == 0.01)
	setfield /kinetics/CaReg/CaStore         n      {18}
	setfield /kinetics/CaReg/calreticulin    n {1031226}
	setfield /kinetics/CaReg/calreticulin-Ca n     {773}
	end
elif	(select_num == 90) /* calreticulin */
	setfield /kinetics/CaReg/calreticulin    nInit  {960000 * {ratio}}
	setfield /kinetics/CaReg/calreticulin-Ca nInit   {72000 * {ratio}}
	setfield /kinetics/CaReg/calreticulin    n      {960000 * {ratio}}
	setfield /kinetics/CaReg/calreticulin-Ca n       {72000 * {ratio}}
elif	(select_num == 91) /* [Ca2+]ext */
	setfield /kinetics/CaReg/Ca_ext n {12000000 * {ratio}}
elif	(select_num == 92) /* MgGreen */
	setfield /kinetics/CaBuf/MgGreen        nInit {14940 * {ratio}}
	setfield /kinetics/CaBuf/MgGreen*       nInit {60 * {ratio}}
	setfield /kinetics/CaBuf/MgGreen        n     {14940 * {ratio}}
	setfield /kinetics/CaBuf/MgGreen*       n     {60 * {ratio}}
elif	(select_num == 93) /* parvalbumin */
	setfield /kinetics/CaBuf/parvalbumin    nInit {1380 * {ratio}}
	setfield /kinetics/CaBuf/PV-Ca          nInit {1620 * {ratio}}
	setfield /kinetics/CaBuf/parvalbumin    n     {138 * {ratio}}
	setfield /kinetics/CaBuf/PV-Ca          n     {162 * {ratio}}
elif	(select_num == 94) /* calbindin-D28k */
	setfield /kinetics/CaBuf/Calbindin-D28k nInit {5850 * {ratio}}
	setfield /kinetics/CaBuf/CB-2Ca         nInit {150 * {ratio}}
	setfield /kinetics/CaBuf/Calbindin-D28k n     {5850 * {ratio}}
	setfield /kinetics/CaBuf/CB-2Ca         n     {150 * {ratio}}
elif	(select_num == 95) /* Low Affinity Buffer 1 */
	setfield /kinetics/CaBuf/LowAffBuf      nInit {5997 * {ratio}}
	setfield /kinetics/CaBuf/LAB-Ca         nInit {3 * {ratio}}
	setfield /kinetics/CaBuf/LowAffBuf      n     {5997 * {ratio}}
	setfield /kinetics/CaBuf/LAB-Ca         n     {3 * {ratio}}
elif	(select_num == 96) /* Low Affinity Buffer 2 */
	setfield /kinetics/CaBuf/LowAffBuf2     nInit {6000 * {ratio}}
	setfield /kinetics/CaBuf/LowAffBuf2     n     {6000 * {ratio}}
end
end


function resize_param(select_num)
	int select_num

if	(select_num ==  1)
	setfield /kinetics/mGluR/Glu_bind_mGluR kf {11.111 /1.2}
	setfield /kinetics/mGluR/Glu_bind_mGluR kb {100.0}
elif	(select_num ==  2)
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kf {11.111 /1.2}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kb {100.0}
elif	(select_num ==  3)
	setfield /kinetics/mGluR/mGluR_bind_Gq kf {2.0 /1.2}
	setfield /kinetics/mGluR/mGluR_bind_Gq kb {100.0}
elif	(select_num ==  4)
	setfield /kinetics/mGluR/mGluR-Glu_bind_Gq kf {2.0 /1.2}
	setfield /kinetics/mGluR/mGluR-Glu_bind_Gq kb {100.0}
elif	(select_num ==  5)
	setfield /kinetics/mGluR/Basal_ActGq kf {0.0001}
elif	(select_num ==  6)
	setfield /kinetics/mGluR/Trimerize_Gq kf {6.0 /1.2}

elif	(select_num ==  7)
	setfield /kinetics/PLC/PLC-PIP2_bind_Ca kf {300.0 /1.2}
	setfield /kinetics/PLC/PLC-PIP2_bind_Ca kb {100.0}
elif	(select_num ==  8)
	setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kf {900.0 /1.2}
	setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kb {30.0}
elif	(select_num ==  9)
	setfield /kinetics/PLC/PLC-PIP2_bind_Gq kf {800.0 /1.2}
	setfield /kinetics/PLC/PLC-PIP2_bind_Gq kb {40.0}
elif	(select_num == 10)
	setfield /kinetics/PLC/PLC-PIP2-Ca_bind_Gq kf {1200.0 /1.2}
	setfield /kinetics/PLC/PLC-PIP2-Ca_bind_Gq kb {6.0}
elif	(select_num == 11)
	setfield /kinetics/PLC/PLC-Ca_bind_Gq kf {1200.0 /1.2}
	setfield /kinetics/PLC/PLC-Ca_bind_Gq kb {6.0}
elif	(select_num == 12)
	setfield /kinetics/PLC/PLC-Ca_bind_PIP2 kf {1.0 /1.2}
	setfield /kinetics/PLC/PLC-Ca_bind_PIP2 kb {170.0}
elif	(select_num == 13)
	setfield /kinetics/PLC/PLC-Ca-Gq_bind_PIP2 kf {1.0 /1.2}
	setfield /kinetics/PLC/PLC-Ca-Gq_bind_PIP2 kb {170.0}
elif	(select_num == 14)
	setfield /kinetics/IP3deg/IP3K_bind_Ca kf {1111.1 /60 /60}
	setfield /kinetics/IP3deg/IP3K_bind_Ca kb {100.0}
elif	(select_num == 15)
	setfield /kinetics/IP3deg/IP3K-2Ca_bind_IP3 kf {100.0 /60}
	setfield /kinetics/IP3deg/IP3K-2Ca_bind_IP3 kb {80.0}
elif	(select_num == 16)
	setfield /kinetics/IP3deg/IP5P_bind_IP3 kf {9.0 /60}
	setfield /kinetics/IP3deg/IP5P_bind_IP3 kb {72.0}
elif	(select_num == 17)
	setfield /kinetics/IP3R/IP3R_bind_IP3 kf {1000.0 /60}
	setfield /kinetics/IP3R/IP3R_bind_IP3 kb {25800.0}
elif	(select_num == 18)
	setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kf {8000.0 /60}
	setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kb {2000.0}
elif	(select_num == 19)
	setfield /kinetics/IP3R/IP3R_bind_Ca kf {8.8888 /60}
	setfield /kinetics/IP3R/IP3R_bind_Ca kb {5.0}
elif	(select_num == 20)
	setfield /kinetics/IP3R/IP3R-Ca_bind_Ca kf {20.0 /60}
	setfield /kinetics/IP3R/IP3R-Ca_bind_Ca kb {10.0}
elif	(select_num == 21)
	setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca kf {40.0 /60}
	setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca kb {15.0}
elif	(select_num == 22)
	setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca kf {60.0 /60}
	setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca kb {20.0}
elif	(select_num == 23)
	setfield /kinetics/CaReg/IP3R/proto/IP3R/IP3R_Ca_channel perm {450.0}
elif	(select_num == 24)
	setfield /kinetics/CaReg/SERCA_bind_2Ca kf {17417.0 /60 /60}
	setfield /kinetics/CaReg/SERCA_bind_2Ca kb {1000.0}
elif	(select_num == 25)
	setfield /kinetics/CaReg/Ca_Leak_from_ER/Ca_Leak_chan_from_ER perm {15.0}
elif	(select_num == 26)
	setfield /kinetics/CaReg/PMCA_bind_Ca kf {25000.0 /60}
	setfield /kinetics/CaReg/PMCA_bind_Ca kb {2000.0}
elif	(select_num == 27)
	setfield /kinetics/CaReg/NCX_bind_2Ca kf {93.827 /60 /60}
	setfield /kinetics/CaReg/NCX_bind_2Ca kb {4000.0}
elif	(select_num == 28)
	setfield /kinetics/CaReg/Ca_Leak_from_ext/Ca_Leak_chan_from_ext perm {10.0}
elif	(select_num == 29)
	setfield /kinetics/CaReg/Ca_bind_calreticulin kf {0.1 /12}
	setfield /kinetics/CaReg/Ca_bind_calreticulin kb {200.0}
elif	(select_num == 30)
	setfield /kinetics/CaBuf/Ca_bind_MgGreen kf {1000.0 /60}
	setfield /kinetics/CaBuf/Ca_bind_MgGreen kb {19000.0}
elif	(select_num == 31)
	setfield /kinetics/CaBuf/PV_bind_Ca kf {18.5 /60}
	setfield /kinetics/CaBuf/PV_bind_Ca kb {0.95}
elif	(select_num == 32)
	setfield /kinetics/CaBuf/CB_bind_2Ca kf {87.0 /60 /60}
	setfield /kinetics/CaBuf/CB_bind_2Ca kb {11.275}
elif	(select_num == 33)
	setfield /kinetics/CaBuf/LAB_bind_Ca kf {10.0 /60}
	setfield /kinetics/CaBuf/LAB_bind_Ca kb {1000.0}
elif	(select_num == 34)
	setfield /kinetics/CaBuf/LAB2_bind_2Ca kf {10.0 /60 /60}
	setfield /kinetics/CaBuf/LAB2_bind_2Ca kb {4000.0}
elif	(select_num == 35)
	setfield /kinetics/mGluR/Glu_bind_mGluR kf {9.259259}
        setfield /kinetics/mGluR/Glu_bind_mGluR kb {100.0}
elif	(select_num == 36)
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kf {9.259259}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kb {100.0}
elif	(select_num == 37)
	setfield /kinetics/mGluR/mGluR_bind_Gq kf {1.666667}
	setfield /kinetics/mGluR/mGluR_bind_Gq kb {100.0}
elif	(select_num == 38)
	setfield /kinetics/mGluR/mGluR-Glu_bind_Gq kf {1.666667}
	setfield /kinetics/mGluR/mGluR-Glu_bind_Gq kb {100.0}
elif	(select_num == 39)
	setfield /kinetics/PLC/PLC-PIP2_bind_Ca kf {250.0}
	setfield /kinetics/PLC/PLC-PIP2_bind_Ca kb {100.0}
elif	(select_num == 40)
	setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kf {750.0}
	setfield /kinetics/PLC/PLC-PIP2-Gq_bind_Ca kb {30.0}
elif	(select_num == 41)
	setfield /kinetics/PLC/PLC-PIP2_bind_Gq kf {666.6667}
	setfield /kinetics/PLC/PLC-PIP2_bind_Gq kb {40.0}
elif	(select_num == 42)
	setfield /kinetics/PLC/PLC-PIP2-Ca_bind_Gq kf {1000.0}
	setfield /kinetics/PLC/PLC-PIP2-Ca_bind_Gq kb {6.0}
elif	(select_num == 43)
	setfield /kinetics/PLC/PLC-Ca_bind_Gq kf {1000.0}
	setfield /kinetics/PLC/PLC-Ca_bind_Gq kb {6.0}
elif	(select_num == 44)
	setfield /kinetics/PLC/PLC-Ca_bind_PIP2 kf {0.833333}
	setfield /kinetics/PLC/PLC-Ca_bind_PIP2 kb {170.0}
elif	(select_num == 45)
	setfield /kinetics/PLC/PLC-Ca-Gq_bind_PIP2 kf {0.833333}
	setfield /kinetics/PLC/PLC-Ca-Gq_bind_PIP2 kb {170.0}
elif	(select_num == 46)
	setfield /kinetics/IP3deg/IP3K_bind_Ca kf {0.308642}
	setfield /kinetics/IP3deg/IP3K_bind_Ca kb {100.0}
elif	(select_num == 47)
	setfield /kinetics/IP3deg/IP3K-2Ca_bind_IP3 kf {1.666667}
	setfield /kinetics/IP3deg/IP3K-2Ca_bind_IP3 kb {80.0}
elif	(select_num == 48)
	setfield /kinetics/IP3deg/IP5P_bind_IP3 kf {0.15}
	setfield /kinetics/IP3deg/IP5P_bind_IP3 kb {72.0}
elif	(select_num == 49)
	setfield /kinetics/IP3R/IP3R_bind_IP3 kf {16.66667}
	setfield /kinetics/IP3R/IP3R_bind_IP3 kb {25800.0}
elif	(select_num == 50)
	setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kf {133.33333}
	setfield /kinetics/IP3R/IP3R-IP3_bind_Ca kb {2000.0}
elif	(select_num == 51)
	setfield /kinetics/IP3R/IP3R_bind_Ca kf {0.1481481}
	setfield /kinetics/IP3R/IP3R_bind_Ca kb {5.0}
elif	(select_num == 52)
	setfield /kinetics/IP3R/IP3R-Ca_bind_Ca kf {0.3333333}
	setfield /kinetics/IP3R/IP3R-Ca_bind_Ca kb {10.0}
elif	(select_num == 53)
	setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca kf {0.6666667}
	setfield /kinetics/IP3R/IP3R-2Ca_bind_Ca kb {15.0}
elif	(select_num == 54)
	setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca kf {1.0}
	setfield /kinetics/IP3R/IP3R-3Ca_bind_Ca kb {20.0}
elif	(select_num == 55)
	setfield /kinetics/CaReg/SERCA_bind_2Ca kf {4.8380556}
	setfield /kinetics/CaReg/SERCA_bind_2Ca kb {1000.0}
elif	(select_num == 56)
	setfield /kinetics/CaReg/PMCA_bind_Ca kf {416.6667}
	setfield /kinetics/CaReg/PMCA_bind_Ca kb {2000.0}
elif	(select_num == 57)
	setfield /kinetics/CaReg/NCX_bind_2Ca kf {0.0260631}
	setfield /kinetics/CaReg/NCX_bind_2Ca kb {4000.0}
elif	(select_num == 58)
	setfield /kinetics/CaReg/Ca_bind_calreticulin kf {0.0083333}
	setfield /kinetics/CaReg/Ca_bind_calreticulin kb {200.0}
elif	(select_num == 59)
	setfield /kinetics/CaBuf/Ca_bind_MgGreen kf {16.666667}
	setfield /kinetics/CaBuf/Ca_bind_MgGreen kb {19000.0}
elif	(select_num == 60)
	setfield /kinetics/CaBuf/PV_bind_Ca kf {0.3083333}
	setfield /kinetics/CaBuf/PV_bind_Ca kb {0.95}
elif	(select_num == 61)
	setfield /kinetics/CaBuf/CB_bind_2Ca kf {0.0241667}
	setfield /kinetics/CaBuf/CB_bind_2Ca kb {11.275}
elif	(select_num == 62)
	setfield /kinetics/CaBuf/LAB_bind_Ca kf {0.1666667}
	setfield /kinetics/CaBuf/LAB_bind_Ca kb {1000.0}
elif	(select_num == 63)
	setfield /kinetics/CaBuf/LAB2_bind_2Ca kf {0.0027778}
	setfield /kinetics/CaBuf/LAB2_bind_2Ca kb {4000.0}

elif	(select_num == 64)
	setfield /kinetics/mGluR/Activate_Gq kf {116.0}
elif	(select_num == 65)
        setfield /kinetics/mGluR/Inact_Gq kf {0.02}
elif	(select_num == 66)
	setfield /kinetics/PLC/IP3_prd_without_Gq kf {2.0}
elif	(select_num == 67)
	setfield /kinetics/PLC/IP3_prd_with_Gq kf {160.0}
elif	(select_num == 68)
	setfield /kinetics/PLC/inact_Gq_by_PLC-PIP2 kf {8.0}
elif	(select_num == 69)
	setfield /kinetics/PLC/inact_Gq_by_PLC-PIP2-Ca kf {8.0}
elif	(select_num == 70)
	setfield /kinetics/PLC/inact_Gq_by_PLC-Ca kf {8.0}
elif	(select_num == 71)
	setfield /kinetics/IP3deg/IP3K_deg_IP3 kf {20.0}
elif	(select_num == 72)
	setfield /kinetics/IP3deg/IP5P_deg_IP3 kf {18.0}
elif	(select_num == 73)
	setfield /kinetics/CaReg/SERCA_uptake kf {250.0}
elif	(select_num == 74)
	setfield /kinetics/CaReg/PMCA_uptake kf {500.0}
elif	(select_num == 75)
	setfield /kinetics/CaReg/NCX_uptake kf {1000.0}

elif	(select_num == 76) /* Glu */
	setfield /kinetics/mGluR/Glu_bind_mGluR kf {11.111 /1.2}
        setfield /kinetics/mGluR/Glu_bind_mGluR kb {100.0}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kf {11.111 /1.2}
	setfield /kinetics/mGluR/Glu_bind_mGluR-Gq kb {100.0}
elif	(select_num == 77) /* mGluR */
	setfield /kinetics/mGluR/mGluR    nInit  {10}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {8}
	setfield /kinetics/mGluR/Gq-GDP   nInit  {52}
	setfield /kinetics/mGluR/mGluR    n      {10}
	setfield /kinetics/mGluR/mGluR-Gq n       {8}
	setfield /kinetics/mGluR/Gq-GDP   n      {52}
elif	(select_num == 78) /* Gq */
	setfield /kinetics/mGluR/mGluR    nInit  {10}
	setfield /kinetics/mGluR/mGluR-Gq nInit   {8}
	setfield /kinetics/mGluR/Gq-GDP   nInit  {52}
	setfield /kinetics/mGluR/mGluR    n      {10}
	setfield /kinetics/mGluR/mGluR-Gq n       {8}
	setfield /kinetics/mGluR/Gq-GDP   n      {52}
elif	(select_num == 79) /* PIP2 */
	setfield /kinetics/PLC/PIP2        nInit  {5000}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.5}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.5}
	setfield /kinetics/PLC/PIP2        n      {5000}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.5}
	setfield /kinetics/PLC/PLC-Ca      n       {0.5}
elif	(select_num == 80) /* PLC */
	setfield /kinetics/PLC/PLC-PIP2    nInit   {42}
	setfield /kinetics/PLC/PLC-PIP2-Ca nInit   {7.5}
	setfield /kinetics/PLC/PLC-Ca      nInit   {0.5}
	setfield /kinetics/PLC/PLC-PIP2    n       {42}
	setfield /kinetics/PLC/PLC-PIP2-Ca n       {7.5}
	setfield /kinetics/PLC/PLC-Ca      n       {0.5}
elif	(select_num == 81) /* IP3 */
	setfield /kinetics/PLC/IP3_PSD              n {0.12}
	setfield /kinetics/IP3deg/IP3_spine         n {6}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n {58.8}
	setfield /kinetics/IP3deg/IP5P-IP3          n {1.2}
elif	(select_num == 82) /* IP3 3-kinase */
	setfield /kinetics/IP3deg/IP3_3-kinase nInit  {52}
	setfield /kinetics/IP3deg/IP3K-2Ca     nInit   {2}
	setfield /kinetics/IP3deg/IP3_3-kinase n      {52}
	setfield /kinetics/IP3deg/IP3K-2Ca     n       {2}
elif	(select_num == 83) /* IP3 5-phosphatase */
	setfield /kinetics/IP3deg/IP3_5-phosphatase nInit  {58.8}
	setfield /kinetics/IP3deg/IP5P-IP3          nInit   {1.2}
	setfield /kinetics/IP3deg/IP3_5-phosphatase n      {58.8}
	setfield /kinetics/IP3deg/IP5P-IP3          n       {1.2}
elif	(select_num == 84) /* IP3R */
	setfield /kinetics/IP3R/IP3Rec    nInit {14.22}
	setfield /kinetics/IP3R/IP3R-IP3  nInit  {0.06}
	setfield /kinetics/IP3R/IP3R_open nInit  {0.01}
	setfield /kinetics/IP3R/IP3R-Ca   nInit  {1.5}
	setfield /kinetics/IP3R/IP3R-2Ca  nInit  {0.18}
	setfield /kinetics/IP3R/IP3R-3Ca  nInit  {0.03}
	setfield /kinetics/IP3R/IP3R-4Ca  nInit  {0.0}
	setfield /kinetics/IP3R/IP3Rec    n     {14.22}
	setfield /kinetics/IP3R/IP3R-IP3  n      {0.06}
	setfield /kinetics/IP3R/IP3R_open n      {0.01}
	setfield /kinetics/IP3R/IP3R-Ca   n      {1.5}
	setfield /kinetics/IP3R/IP3R-2Ca  n      {0.18}
	setfield /kinetics/IP3R/IP3R-3Ca  n      {0.03}
	setfield /kinetics/IP3R/IP3R-4Ca  n      {0.0}
elif	(select_num == 85) /* [Ca2+]i */
	setfield /kinetics/CaReg/Ca2+/proto/CaSpine    n {3.6}
	setfield /kinetics/CaReg/Ca2+PSD/proto/Ca2+PSD n {0.072}
	setfield /kinetics/IP3deg/IP3_3-kinase         n {52}
	setfield /kinetics/IP3deg/IP3K-2Ca             n {2}
	setfield /kinetics/PLC/PLC-PIP2                n {42}
	setfield /kinetics/PLC/PLC-PIP2-Ca             n {7.5}
	setfield /kinetics/PLC/PLC-Ca                  n {0.5}
	setfield /kinetics/CaReg/SERCA                 n {148}
	setfield /kinetics/CaReg/SERCA-2Ca             n {7}
	setfield /kinetics/CaReg/PMCA                  n {68}
	setfield /kinetics/CaReg/PMCA-Ca               n {40}
	setfield /kinetics/CaReg/NCX                   n {32}
	setfield /kinetics/CaReg/NCX-2Ca               n {0}
	setfield /kinetics/CaBuf/MgGreen               n {14940}
	setfield /kinetics/CaBuf/MgGreen*              n {60}
	setfield /kinetics/CaBuf/parvalbumin           n {1380}
	setfield /kinetics/CaBuf/PV-Ca                 n {1620}
	setfield /kinetics/CaBuf/Calbindin-D28k        n {5850}
	setfield /kinetics/CaBuf/CB-2Ca                n {150}
elif	(select_num == 86)  /* SERCA */
	setfield /kinetics/CaReg/SERCA     nInit {148}
	setfield /kinetics/CaReg/SERCA-2Ca nInit {7}
	setfield /kinetics/CaReg/SERCA     n     {148}
	setfield /kinetics/CaReg/SERCA-2Ca n     {7}
elif	(select_num == 87)  /* PMCA */
	setfield /kinetics/CaReg/PMCA      nInit {68}
	setfield /kinetics/CaReg/PMCA-Ca   nInit {40}
	setfield /kinetics/CaReg/PMCA      n     {68}
	setfield /kinetics/CaReg/PMCA-Ca   n     {40}
elif	(select_num == 88) /* Na+/Ca2+ exchanger */
	setfield /kinetics/CaReg/NCX       nInit {32}
	setfield /kinetics/CaReg/NCX       n     {32}
elif	(select_num == 89)  /* [Ca2+]ER */
	setfield /kinetics/CaReg/CaStore         n   {1800}
	setfield /kinetics/CaReg/calreticulin    n {960000}
	setfield /kinetics/CaReg/calreticulin-Ca n  {72000}
elif	(select_num == 90) /* calreticulin */
	setfield /kinetics/CaReg/calreticulin    nInit  {960000}
	setfield /kinetics/CaReg/calreticulin-Ca nInit   {72000}
	setfield /kinetics/CaReg/calreticulin    n      {960000}
	setfield /kinetics/CaReg/calreticulin-Ca n       {72000}
elif	(select_num == 91) /* [Ca2+]ext */
	setfield /kinetics/CaReg/Ca_ext n {12000000}
elif	(select_num == 92) /* MgGreen */
	setfield /kinetics/CaBuf/MgGreen        nInit {14940}
	setfield /kinetics/CaBuf/MgGreen*       nInit {60}
	setfield /kinetics/CaBuf/MgGreen        n     {14940}
	setfield /kinetics/CaBuf/MgGreen*       n     {60}
elif	(select_num == 93) /* parvalbumin */
	setfield /kinetics/CaBuf/parvalbumin    nInit {1380}
	setfield /kinetics/CaBuf/PV-Ca          nInit {1620}
	setfield /kinetics/CaBuf/parvalbumin    n     {138}
	setfield /kinetics/CaBuf/PV-Ca          n     {162}
elif	(select_num == 94) /* calbindin-D28k */
	setfield /kinetics/CaBuf/Calbindin-D28k nInit {5850}
	setfield /kinetics/CaBuf/CB-2Ca         nInit {150}
	setfield /kinetics/CaBuf/Calbindin-D28k n     {5850}
	setfield /kinetics/CaBuf/CB-2Ca         n     {150}
elif	(select_num == 95) /* Low Affinity Buffer 1 */
	setfield /kinetics/CaBuf/LowAffBuf      nInit {5997}
	setfield /kinetics/CaBuf/LAB-Ca         nInit {3}
	setfield /kinetics/CaBuf/LowAffBuf      n     {5997}
	setfield /kinetics/CaBuf/LAB-Ca         n     {3}
elif	(select_num == 96) /* Low Affinity Buffer 2 */
	setfield /kinetics/CaBuf/LowAffBuf2     nInit {6000}
	setfield /kinetics/CaBuf/LowAffBuf2     n     {6000}
end
end


function makeIP3(select_num, ratio)
	int   select_num
	float ratio
	str   filefullname

	reset
	echo "Generating parameter number =" {select_num} ", ratio =" {ratio}
	step {0.5}   -time
	vary_param {select_num} {ratio}
        step {1.5001} -time

        filefullname = {"./simresult/figS2BCDE/paramsIP3_param" @ {select_num} @"_ratio"@ {ratio} @ "_IP3.plot"}
        do_save_named_plot /graphs/conc1/IP3_spine.Co {filefullname}
        echo "saved as "{filefullname}

	resize_param {select_num}

	reset
end



function paramsIP3loop(start_n, end_n)
int start_n
int current_n
int end_n

echo "Running from " {start_n} "to" {end_n}

	for(current_n = start_n; current_n <= end_n; current_n = current_n + 1)
	makeIP3 {current_n}   {2.0}
	makeIP3 {current_n}   {5.0}
	makeIP3 {current_n}  {10.0}
	makeIP3 {current_n}  {20.0}
	makeIP3 {current_n}  {50.0}
	makeIP3 {current_n} {100.0}

	makeIP3 {current_n}   {0.5}
	makeIP3 {current_n}   {0.2}
	makeIP3 {current_n}   {0.1}
	makeIP3 {current_n}   {0.05}
	makeIP3 {current_n}   {0.02}
	makeIP3 {current_n}   {0.01}
	end

echo "Simulation has done!"
echo "Type 'quit' to exit GENESIS/kinetikit"

end
