clear

file_head = 'F_CFat'
file_tail = 'msec.plot'
MgGreenTotal = 250;
plot_length = 2001;
data_number = 111;

% Including GENESIS plot files to MATLAB
MgGreen = zeros(plot_length, data_number);
for data_index = 0:(data_number-1)
filefullname = strcat(file_head, int2str(data_index * 10 - 500), file_tail);
transient = load(filefullname);
transient(:,1) = [];
MgGreen(:, data_index + 1)=transient; % put file into transients
end

% Calc total integrate Ca2+ response
for t = 0:(plot_length-1)    
    % Determine from_time
    if t < 500
        from_time(t+1) = t;
    else from_time(t+1) = 500;
    end
    
    % Determine to_time
    if t < 540
        to_time(t+1) = 540 + 500;
    else to_time(t+1) = t + 500;
    end
end

% Convert [MgGreen] to dF/F0
    % Find F0
    F0 = min(min(MgGreen))/MgGreenTotal + 1
    F  = MgGreen/MgGreenTotal + 1;
    dF_rate = (F - F0) * 100;

% calc the time window function 'G'
G = zeros(data_number,1);
for data_index = 0:(data_number-1)
    duration = data_index * 10;
    for t=from_time(duration + 1):to_time(duration + 1)
        G(data_index + 1) = G(data_index + 1) + dF_rate(t+1, data_index + 1);
    end
    G(data_index + 1) = G(data_index + 1) / (to_time(duration + 1) - from_time(duration + 1) );
end


interval = -500:10:600;
PFalone_F = mean(dF_rate(501:1041,111)) % tw =  600 ms
CFalone_F = mean(dF_rate(1:500,1))      % tw = -500 ms
plot(interval, G, 'k-');
hold on
axis([-500 1000 0 12])
set(gca,'xtick',[-400 -300 -200 -100 0 100 200 300 400 500 600])
set(gca,'XTickLabel','-400||-200||0||200||400||')
set(gca,'ytick',[0 2 4 6 8 10 12])
set(gca,'YTickLabel','0|2|4|6|8||')
set(gca,'Tickdir','out')
box off
title('Time Window')
xlabel('PF -> CF interval (\Deltat ms)')
ylabel('Averaged Ca2+ response (% \DeltaF/F0)')


%G_floor = G - min(G);
min_G = min(G(1:111));
G_floor(1:111) = G(1:111) - min_G;
G_area = sum(G_floor(1:111));
norm_G(1:111) = G_floor(1:111) ./ G_area;
sum(norm_G(1:111))

mean_Gaussian = 0;
for index = 1:111
       mean_Gaussian = interval(index) * norm_G(index) + mean_Gaussian;
end
var_Gaussian = 0;
for index = 1:111
    var_Gaussian = (interval(index) - mean_Gaussian)*(interval(index) - mean_Gaussian) * norm_G(index) + var_Gaussian;
end
peak_Gaussian = G_area / sqrt(2 * pi * var_Gaussian) + min_G
mean_Gaussian
var_Gaussian
sigma = sqrt(var_Gaussian)
halfwidth = sqrt(2 * log(2)) * sigma

index = -500:10:600;
fit_G = 1/sqrt(2 * pi)/sigma * exp(-(index - mean_Gaussian).*(index - mean_Gaussian)/var_Gaussian/2) * G_area * 10 + min_G;
plot(index, fit_G, 'm')